@@ -386,19 +386,20 @@ END
          '"install","HTTP::Server::Simple")\'',
          '__display__');
    }
-   my $show=<<END;
+      $show=<<END;
 ########################################
 
    INSTALLING Perl::Critic
 
 ########################################
 END
-   print $show;
-   cmd_raw($handle,
-      'perl -MCPAN -e \'CPAN::Shell->notest('.
-      '"install","Perl::Critic")\'',
-      '__display__');
-   $show=<<END;
+      print $show;
+      cmd_raw($handle,
+         'perl -MCPAN -e \'CPAN::Shell->notest('.
+         '"install","Perl::Critic")\'',
+         '__display__');
+   }
+   my $show=<<END;
 ########################################
 
    INSTALLING ExtUtils::Embed
@@ -718,6 +719,111 @@ END
    cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Unicode",'__display__');
    $show=<<END;
 
+########################################
+
+   INSTALLING DBIx::Class::PassphraseColumn
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan DBIx::Class::PassphraseColumn",'__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Authen::Passphrase::BlowfishCrypt
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Authen::Passphrase::BlowfishCrypt",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING CatalystX::SimpleLogin
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan CatalystX::SimpleLogin",'__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Catalyst::Plugin::Session
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Session",'__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Catalyst::Plugin::Session::Store::Memcached
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Session::Store::Memcached",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Catalyst::Plugin::Session::State::Cookie
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Session::State::Cookie",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Catalyst::Plugin::Authentication
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Authentication",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Catalyst::Authentication::Store::DBIx::Class
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::Authentication::Store::DBIx::Class",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Catalyst::Plugin::Authorization::Roles
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Authorization::Roles",
+           '__display__');
+   $show=<<END;
+
 ########################################
 
    INSTALLING Finance::Quote
@@ -762,10 +868,119 @@ END
    ($stdout,$stderr)=$handle->cmd("catalyst.pl AdventREST",'__display__');
    ($stdout,$stderr)=$handle->cwd("AdventREST");
    ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
+   my $pm_path="./lib/AdventREST.pm";
+   $ad="    Session%NL%".
+       "    Session::Store::Memcached%NL%".
+       "    Session::State::Cookie%NL%".
+       "    Authentication%NL%".
+       "    Authorization::Roles%NL%".
+       "    +CatalystX::SimpleLogin%NL%";
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}sed -i '/Static::Simple$/a$ad' $pm_path");
+   $ad="__PACKAGE__->config(%NL%".
+       "   authentication => {%NL%".
+       "      default_realm => %SQ%users%SQ%,%NL%".
+       "      realms        => {%NL%".
+       "         users => {%NL%".
+       "            credential => {%NL%".
+       "               class          => %SQ%Password%SQ%,%NL%".
+       "               password_field => %SQ%password%SQ%,%NL%".
+       "               password_type  => %SQ%self_check%SQ%%NL%".
+       "            },%NL%".
+       "            store => {%NL%".
+       "               class         => %SQ%DBIx::Class%SQ%,%NL%".
+       "               user_model    => %SQ%DB::User%SQ%,%NL%".
+       "               role_relation => %SQ%roles%SQ%,%NL%".
+       "               role_field    => %SQ%name%SQ%,%NL%".
+       "            }%NL%".
+       "         }%NL%".
+       "      },%NL%".
+       "   },%NL%".
+       "   %SQ%Controller::Login%SQ% => {%NL%".
+       "       traits => [%SQ%-RenderAsTTTemplate%SQ%],%NL%".
+       "       login_form_args => {%NL%".
+       "           authenticate_args => { active => %SQ%Y%SQ% },%NL%".
+       "       },%NL%".
+       "   },%NL%".
+       ");%NL%%NL%";
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}sed -i '/__PACKAGE__[-][>]setup[(][)]/i$ad' $pm_path");
+   ($stdout,$stderr)=$handle->cmd( # bash shell specific
+      "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $pm_path");
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $pm_path");
+   ($stdout,$stderr)=$handle->cmd("mkdir -vp root/src/login",'__display__');
+   ($stdout,$stderr)=$handle->cmd("touch root/src/login/login.tt2",
+      '__display__');
+   my $content=<<'ENDD';
+[% META title = 'Welcome to FullAuto: Please Log In' %]
+<div>
+    [% FOR field IN login_form.error_fields %]
+        [% FOR error IN field.errors %]
+            <p><span style=\\x22color: red;\\x22>[% field.label _ ': ' _ error %]</span></p>
+        [% END %]
+    [% END %]
+</div>
+ 
+<div>
+    <form id=\\x22login_form\\x22 method=\\x22post\\x22 action=\\x22[% c.req.uri %]\\x22>
+        <fieldset style=\\x22border: 0;\\x22>
+            <table>
+                <tr>
+                    <td><label class=\\x22label\\x22 for=\\x22username\\x22>Username:</label></td>
+                    <td><input type=\\x22text\\x22 name=\\x22username\\x22 value=\\x22\\x22 /></td>
+                </tr>
+                <tr>
+                    <td><label class=\\x22label\\x22 for=\\x22password\\x22>Password:</label></td>
+                    <td><input type=\\x22password\\x22 name=\\x22password\\x22 value=\\x22\\x22 /></td>
+                </tr>
+                <tr><td><input type=\\x22submit\\x22 name=\\x22submit\\x22 value=\\x22Login\\x22 /></td></tr>
+            </table>
+        </fieldset>
+    </form>
+</div>
+ENDD
+   ($stdout,$stderr)=$handle->cmd(
+      "echo \"$content\" > root/src/login/login.tt2");
    ($stdout,$stderr)=$handle->cmd("mkdir -v db lib/AdventREST/Schema",
       '__display__');
    my $db_sql="db.sql";
-   my $content=<<'END';
+   $content=<<'END';
+DROP TABLE IF EXISTS users;
+DROP TABLE IF EXISTS roles;
+DROP TABLE IF EXISTS user_roles;
+ 
+CREATE TABLE users (
+    id INTEGER PRIMARY KEY,
+    active CHAR(1) NOT NULL,
+    username TEXT NOT NULL UNIQUE,
+    password TEXT NOT NULL,
+    password_expires TIMESTAMP,
+    name TEXT NOT NULL,
+    email_address TEXT NOT NULL,
+    phone_number TEXT,
+    mail_address TEXT
+);
+ 
+CREATE TABLE roles (
+    id INTEGER PRIMARY KEY,
+    name TEXT NOT NULL UNIQUE
+);
+ 
+CREATE TABLE user_roles (
+    user_id INTEGER NOT NULL REFERENCES users(id) ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
+    role_id INTEGER NOT NULL REFERENCES roles(id) ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
+    PRIMARY KEY (user_id, role_id)
+);
+ 
+INSERT INTO users (username, active, name, email_address, password) VALUES (
+    'admin', 'Y', 'Administrator', 'admin@fullauto.com', 'password'
+);
+INSERT INTO roles (name) VALUES ('admin');
+INSERT INTO roles (name) VALUES ('can_edit');
+INSERT INTO user_roles (user_id, role_id) VALUES (
+    (SELECT id FROM users WHERE username = 'admin'),
+    (SELECT id FROM roles WHERE name     = 'admin')
+);
 CREATE TABLE user (
  user_id TYPE text NOT NULL PRIMARY KEY,
  fullname TYPE text NOT NULL,
@@ -1261,15 +1476,12 @@ END
       "./script/adventrest_create.pl model TheSchwartz",'__display__');
    $ad='__PACKAGE__->config( class => "TheSchwartz" );%NL%%NL%'. # %NL% is newline
       'sub mangle_arguments { %{ $_[1]->{args} } }%NL%';
-print "LINE 1264\n";
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/Catalyst::Model/a$ad\' ".
       "./lib/AdventREST/Model/TheSchwartz.pm");
-print "LINE 1265\n";
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
       "./lib/AdventREST/Model/TheSchwartz.pm");
-print "LINE 1266\n";
    $content=<<END;
 Model::TheSchwartz:
   args:
@@ -1277,9 +1489,7 @@ Model::TheSchwartz:
     databases:
       - dsn: dbi:SQLite:__path_to(db/theschwartz.sqlt)__
 END
-print "LINE 1267\n";
    ($stdout,$stderr)=$handle->cmd("echo \"$content\" >> adventrest.yml");
-print "LINE 1268\n";
    $ad="use Net::FullAuto;%NL%".
        "use ZMQ::LibZMQ4;%NL%".
        "use ZMQ::Constants qw(:all);%NL%".
@@ -1485,26 +1695,20 @@ print "LINE 1268\n";
        "   setpgrp(0,0) unless \$Fork->in_parent;%NL%".
        "%NL%".
        "}%NL%";
-print "LINE 1269\n";
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/use Catalyst::ScriptRunner/i$ad\' ".
       "./script/adventrest_server.pl");
-print "LINE 1270\n";
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
       "./script/adventrest_server.pl");
-print "LINE 1271\n";
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
       "./script/adventrest_server.pl");
-print "LINE 1272\n";
    ($stdout,$stderr)=$handle->cwd("..");
-print "LINE 1273\n";
    ($stdout,$stderr)=$handle->put("fullauto.pem");
    ($stdout,$stderr)=$handle->cmd(
       "wget --random-wait --progress=dot ".
       "https://github.com/pangyre/p5-myapp-10in10/archive/master.zip",
       '__display__');
-print "LINE 1274\n";
    ($stdout,$stderr)=$handle->cmd("unzip master.zip",'__display__');
    ($stdout,$stderr)=$handle->cmd("rm -rvf master.zip",'__display__');
    ($stdout,$stderr)=$handle->cwd("p5-myapp-10in10-master");
